"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var helpers_1 = require("./helpers");
var types_1 = require("./types");
// KAMIL: react has some ts packages selected by default (we might want to change it because of flow)
exports.plugins = [
    {
        name: "TypeScript " + helpers_1.italic('(required by other typescript plugins)'),
        package: 'graphql-codegen-typescript',
        value: 'typescript',
        available: function () { return true; },
        shouldBeSelected: function (tags) { return oneOf(tags, types_1.Tags.angular, types_1.Tags.stencil, types_1.Tags.react, types_1.Tags.typescript); }
    },
    {
        name: "TypeScript Operations " + helpers_1.italic('(operations and fragments)'),
        package: 'graphql-codegen-typescript-operations',
        value: 'typescript-operations',
        available: hasTag(types_1.Tags.browser),
        shouldBeSelected: function (tags) {
            return oneOf(tags, types_1.Tags.angular, types_1.Tags.stencil, types_1.Tags.react) || allOf(tags, types_1.Tags.typescript, types_1.Tags.browser);
        }
    },
    {
        name: "TypeScript Resolvers " + helpers_1.italic('(strongly typed resolve functions)'),
        package: 'graphql-codegen-typescript-resolvers',
        value: 'typescript-resolvers',
        available: hasTag(types_1.Tags.node),
        shouldBeSelected: function (tags) { return allOf(tags, types_1.Tags.typescript, types_1.Tags.node); }
    },
    {
        name: "TypeScript Apollo Angular " + helpers_1.italic('(typed GQL services)'),
        package: 'graphql-codegen-typescript-apollo-angular',
        value: 'typescript-apollo-angular',
        available: hasTag(types_1.Tags.angular),
        shouldBeSelected: function () { return true; }
    },
    {
        name: "TypeScript React Apollo " + helpers_1.italic('(typed components and HOCs)'),
        package: 'graphql-codegen-typescript-react-apollo',
        value: 'typescript-react-apollo',
        available: hasTag(types_1.Tags.react),
        shouldBeSelected: function () { return true; }
    },
    {
        name: "TypeScript Stencil Apollo " + helpers_1.italic('(typed components)'),
        package: 'graphql-codegen-typescript-stencil-apollo',
        value: 'typescript-stencil-apollo',
        available: hasTag(types_1.Tags.stencil),
        shouldBeSelected: function () { return true; }
    },
    {
        name: "TypeScript MongoDB " + helpers_1.italic('(typed MongoDB objects)'),
        package: 'graphql-codegen-typescript-mongodb',
        value: 'typescript-mongodb',
        available: hasTag(types_1.Tags.node),
        shouldBeSelected: function () { return false; }
    },
    {
        name: "TypeScript GraphQL files modules " + helpers_1.italic('(declarations for .graphql files)'),
        package: 'graphql-codegen-typescript-graphql-files-modules',
        value: 'typescript-graphql-files-modules',
        available: hasTag(types_1.Tags.browser),
        shouldBeSelected: function () { return false; }
    },
    {
        name: "Introspection Fragment Matcher " + helpers_1.italic('(for Apollo Client)'),
        package: 'graphql-codegen-fragment-matcher',
        value: 'fragment-matcher',
        available: hasTag(types_1.Tags.browser),
        shouldBeSelected: function () { return false; }
    }
];
function hasTag(tag) {
    return function (tags) { return tags.includes(tag); };
}
function oneOf(list) {
    var items = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        items[_i - 1] = arguments[_i];
    }
    return list.some(function (i) { return items.includes(i); });
}
function allOf(list) {
    var items = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        items[_i - 1] = arguments[_i];
    }
    return items.every(function (i) { return list.includes(i); });
}
//# sourceMappingURL=plugins.js.map